@@ -263,10 +263,8 @@ class Repository:
         Executes sql query. Make sure you use :parameter for parameters
         '''
         q = text(query)
-        result = self.engine.execute(q, parameters).all()
-
-        for row in result:
-            pass
+        result = self.engine.execute(q, parameters).fetchall()
+        return result
 
     def assign(self, entity, prop, value):
         loaded_value = self.load(entity=value)
